package fr.cnam.in01.db4o;

import java.io.File;

import android.app.Activity;
import android.os.Bundle;
import android.os.Environment;
import android.widget.TextView;

import com.db4o.Db4oEmbedded;
import com.db4o.ObjectContainer;
import com.db4o.ObjectSet;
import com.db4o.config.EmbeddedConfiguration;
import com.db4o.query.Predicate;
import com.db4o.query.Query;

import fr.cnam.in01.db4o.businessModel.Book;
import fr.cnam.in01.db4o.businessModel.Department;
import fr.cnam.in01.db4o.businessModel.Employe;
import fr.cnam.in01.db4o.businessModel.Person;
import fr.cnam.in01.db4o.R.*;

public class MainActivity extends Activity {

	private TextView textview;

	/**
	 Called when the activity is first created.
	 */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);

		new File(DB_FILE).delete();
		EmbeddedConfiguration config = Db4oEmbedded.newConfiguration();
		ObjectContainer db = Db4oEmbedded.openFile(config, DB_FILE);

        textview = (TextView)findViewById(id.textview);
        textview.append("\n");

		doSomeBookStuff(db);
		doSomeHierarchicalStuff(db);
		doQBEDBStuff(db);
		doNQDBStuff(db);
		doSODADBStuff(db);

		db.close();
	}

	private static final String root = Environment.getExternalStorageDirectory().toString();
	public static final String DB_FILE = root + "/db.db4o";

	private void doSomeBookStuff(ObjectContainer db) {
		Book book1 = new Book("Croc Blanc", "2010034031", 248);
		Book book2 = new Book("L'appel de la forêt", "2253039861", 158);

		db.store(book1);
		db.store(book2);

		textview.append("\n");

		ObjectSet<Book> result = db.queryByExample(Book.class);
		for (Book p : result) {
			textview.append("DB4O SELECT ALL Book " + p + " loaded !\n");
		}
	}
	
	private void doSomeHierarchicalStuff(ObjectContainer db) {
		Department root = new Department("T");
		Department td = new Department("D");
		Department to = new Department("O");
		root.addChild(td);
		root.addChild(to);

		db.store(root);

		db.store(new Person("Johanna", "Caron", 26));
		db.store(new Employe(td, "Yann", "Caron", 34));
		
		textview.append("\n");

		ObjectSet<Person> result = db.queryByExample(Person.class);
		for (Person p : result) {
			textview.append("DB4O HIERARCHICAL Object " + p + " loaded !\n");
		}
	}

	private void doQBEDBStuff(ObjectContainer db) {
		textview.append("\n");

		ObjectSet<Book> result = db.queryByExample(new Book("Croc Blanc", null, 0));
		for (Book p : result) {
			textview.append("DB4O QBE Object " + p + " loaded !\n");
		}
	}

	private void doNQDBStuff(ObjectContainer db) {
		textview.append("\n");

		ObjectSet<Book> result = db.query(new Predicate<Book>() {
			@Override
			public boolean match(Book book) {
				return "Croc Blanc".equals(book.getTitle());
			}
		});
		for (Book p : result) {
			textview.append("DB4O NQ1 Object " + p + " loaded !\n");
		}

		ObjectSet<Employe> result2 = db.query(new Predicate<Employe>() {

			@Override
			public boolean match(Employe person) {
				textview.append("NQ2 PREDICATE departement = " + person.getDepartement().getName() + "\n");
				return "TD".equals(person.getDepartement().getName());
			}
		});
		for (Employe e : result2) {
			textview.append("DB4O NQ2 Object " + e + " loaded !\n");
		}
	}

	private void doSODADBStuff(ObjectContainer db) {
		textview.append("\n");

		Query query = db.query();
		query.constrain(Book.class);
		query.descend("title").constrain("Croc Blanc").equal();

		ObjectSet<Book> result = query.execute();

		for (Book p : result) {
			textview.append("DB4O SODA Object " + p + " loaded !\n");
		}
	}
}
