/* 
 * Copyright (C) 2014 cyann
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package fr.cnam.in01.sqlite.data;

import android.content.ContentValues;
import android.database.Cursor;
import fr.cnam.in01.sqlite.businessModel.Book;
import fr.cnam.in01.sqlite.common.AllReadeable;
import fr.cnam.in01.sqlite.common.DataAccessObject;
import fr.cnam.in01.sqlite.common.DataSource;
import java.util.ArrayList;
import java.util.List;

/**
 <p>
 @author cyann
 */
public class BookDAO extends DataAccessObject<Book> implements AllReadeable<Book> {

	public static final String TABLE_NAME = "Book";
	public static final String COL_ID = "id";
	public static final String COL_TITLE = "title";
	public static final String COL_ISBN = "isbn";
	public static final String COL_NBPAGE = "nbPage";

	public static String getQueryCreate() {
		return "CREATE TABLE " + TABLE_NAME + "("
			+ COL_ID + " Integer PRIMARY KEY AUTOINCREMENT, "
			+ COL_TITLE + " Text NOT NULL, "
			+ COL_ISBN + " Text NOT NULL, "
			+ COL_NBPAGE + " Integer NOT NULL"
			+ ");";
	}

	public static String getQueryDrop() {
		return "DROP TABLE IF EXISTS " + TABLE_NAME + ";";
	}

	public BookDAO(DataSource datasource) {
		super(datasource);
	}

	public synchronized Book create(Book pojo) {
		// create associative array
		ContentValues values = new ContentValues();
		values.put(COL_TITLE, pojo.getTitle());
		values.put(COL_ISBN, pojo.getIsbn());
		values.put(COL_NBPAGE, pojo.getNbPage());

		// insert query
		int id = (int) getDB().insert(TABLE_NAME, null, values);

		// update id into pojo
		pojo.setId(id);

		return pojo;
	}
	
	public Book read(Book pojo) {
		// columns
		String[] allColumns = new String[]{COL_ID, COL_TITLE, COL_ISBN, COL_NBPAGE};
		
		// clause
		String clause = COL_ID + " = ?";
		String[] clauseArgs = new String[]{String.valueOf(pojo.getId())};

		// select query
		Cursor cursor = getDB().query(TABLE_NAME, allColumns, "ID = ?", clauseArgs, null, null, null);

		// read cursor
		cursor.moveToFirst();
		pojo.setTitle(cursor.getString(1));
		pojo.setIsbn(cursor.getString(2));
		pojo.setNbPage(cursor.getInt(3));
		cursor.close();

		return pojo;
	}

	public List<Book> readAll() {
		// columns
		String[] allColumns = new String[]{COL_ID, COL_TITLE, COL_ISBN, COL_NBPAGE};

		// select query
		Cursor cursor = getDB().query(TABLE_NAME, allColumns, null, null, null, null, null);

		// iterate on cursor and retreive result
		List<Book> books = new ArrayList<Book>();

		cursor.moveToFirst();
		while (!cursor.isAfterLast()) {
			books.add(new Book(cursor.getInt(0), cursor.getString(1), cursor.getString(2), cursor.getInt(3)));
			cursor.moveToNext();
		}

		cursor.close();

		return books;
	}

	public synchronized Book update(Book pojo) {
		// create associative array
		ContentValues values = new ContentValues();
		values.put(COL_TITLE, pojo.getTitle());
		values.put(COL_ISBN, pojo.getIsbn());
		values.put(COL_NBPAGE, pojo.getNbPage());

		// where clause
		String clause = COL_ID + " = ?";
		String[] clauseArgs = new String[]{String.valueOf(pojo.getId())};

		// update
		getDB().update(TABLE_NAME, values, clause, clauseArgs);
		
		// return the pojo
		return pojo;
	}

	public synchronized void delete(Book pojo) {
		// where clause
		String clause = COL_ID + " = ?";
		String[] clauseArgs = new String[]{String.valueOf(pojo.getId())};
		
		// delete
		getDB().delete(TABLE_NAME, clause, clauseArgs);
	}

}
