/* 
 * Copyright (C) 2014 cyann
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package fr.cnam.in01.sqlite.data;

import android.content.Context;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.util.Log;
import fr.cnam.in01.sqlite.common.DataSource;

/**
 <p>
 @author cyann
 */
public class LibraryDataSource implements DataSource {

	private final LibraryDBHelper helper;
	private SQLiteDatabase db;

	public LibraryDataSource(Context context) {
		helper = new LibraryDBHelper(context);
	}

	@Override
	public SQLiteDatabase getDB() {
		// lazy initialization
		if (db == null) {
			open();
		}
		return db;
	}

	@Override
	public void open() throws SQLException {
		db = helper.getWritableDatabase();
		Log.w(LibraryDataSource.class.getName(), "OPEN DB " + db.getPath());
	}

	@Override
	public void close() {
		helper.close();
	}

	// factories
	public BookDAO newBookDAO() {
		// flyweight ?
		return new BookDAO(this);
	}

}
