package fr.cnam.in01.techniques;

import java.util.List;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;
import android.os.Bundle;
import android.os.IBinder;
import android.support.v7.app.ActionBarActivity;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;

import com.android.vending.billing.IInAppBillingService;
import com.google.ads.AdRequest;
import com.google.ads.AdView;
import com.google.analytics.tracking.android.EasyTracker;
import com.google.analytics.tracking.android.MapBuilder;

import fr.cyann.android.billingService.BillingService;
import fr.cyann.android.billingService.IabException;
import fr.cyann.android.billingService.Purchase;
import fr.cyann.android.billingService.SkuDetail;

public class MainActivity extends ActionBarActivity {

	IInAppBillingService billingService;

	ServiceConnection serviceConn = new ServiceConnection() {
		@Override
		public void onServiceDisconnected(ComponentName name) {
			billingService = null;
		}

		@Override
		public void onServiceConnected(ComponentName name, IBinder service) {
			billingService = IInAppBillingService.Stub.asInterface(service);
			Log.w(this.getClass().getName(), "BILLING SERVICE LOADED "
					+ billingService.toString());
		}
	};

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);

		Button btBilling = (Button) findViewById(R.id.btBilling);
		Button btPurchase = (Button) findViewById(R.id.btPurchase);

		// billing
		bindService(new Intent(
				"com.android.vending.billing.InAppBillingService.BIND"),
				serviceConn, Context.BIND_AUTO_CREATE);

		btBilling.setOnClickListener(new OnClickListener() {

			@Override
			public void onClick(View v) {
				btBilling_onClick(v);
			}
		});

		btPurchase.setOnClickListener(new OnClickListener() {

			@Override
			public void onClick(View v) {
				btPurchase_onClick(v);
			}
		});

		BillingService.getInstance(this).initialize();

		AdView adView = (AdView) findViewById(R.id.ad);
		loadAd(adView);

	}

	private void loadAd(AdView adView) {
		// advertising
		AdRequest adRequest = new AdRequest();
		adRequest.addKeyword("sporting goods, fishing");
		adRequest.addTestDevice("F61A3C0A1FC61AB56B5E559E117B7DCF");
		adView.loadAd(adRequest);
	}

	private void btBilling_onClick(View v) {
		try {
			List<SkuDetail> details = BillingService.getInstance(this)
					.getSkuDetails("product1", "product2");

			for (SkuDetail detail : details) {
				System.out.println("Detail " + detail);
			}

		} catch (IabException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	private void btPurchase_onClick(View v) {
		EasyTracker.getInstance(this).send(MapBuilder.createEvent("ui_action", // Event
																				// category
																				// (required)
				"button_press", // Event action (required)
				"play_button", // Event label
				null) // Event value
				.build());

		try {
			BillingService.getInstance(this).purchase("product1");
		} catch (IabException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {

		Purchase purchase;
		try {
			purchase = BillingService.getInstance(this).handleActivityResult(
					requestCode, resultCode, data);
			if (purchase != null) {
				Log.d(this.getClass().getName(), "Purchase ok " + purchase);
			}
		} catch (IabException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

	}

	@Override
	public void onDestroy() {
		super.onDestroy();
		if (billingService != null) {
			unbindService(serviceConn);
		}
	}

	@Override
	public void onStart() {
		super.onStart();
		EasyTracker.getInstance(this).activityStart(this); // Add this method.
	}

	@Override
	public void onStop() {
		super.onStop();
		EasyTracker.getInstance(this).activityStop(this); // Add this method.
	}
}
