package fr.cnam.pecheurduleman;

import android.content.Context;
import android.location.Criteria;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Bundle;
import android.support.v4.app.FragmentManager;
import android.support.v4.widget.DrawerLayout;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import fr.cnam.pecheurduleman.NavigationDrawerFragment.ScreenAssoc;
import fr.cnam.pecheurduleman.view.BaitFragment;

public class MainActivity extends ActionBarActivity implements
		NavigationDrawerFragment.NavigationDrawerCallbacks {

	/**
	 * Fragment managing the behaviors, interactions and presentation of the
	 * navigation drawer.
	 */
	private NavigationDrawerFragment mNavigationDrawerFragment;

	/**
	 * Used to store the last screen title. For use in
	 * {@link #restoreActionBar()}.
	 */
	private CharSequence mTitle;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);

		mNavigationDrawerFragment = (NavigationDrawerFragment) getSupportFragmentManager()
				.findFragmentById(R.id.navigation_drawer);
		mTitle = getTitle();

		// Set up the drawer.
		mNavigationDrawerFragment.setUp(R.id.navigation_drawer,
				(DrawerLayout) findViewById(R.id.drawer_layout));

		test();
	}

	@Override
	public void onNavigationDrawerItemSelected(int position) {
		ScreenAssoc assoc = NavigationDrawerFragment.SCREEN_ASSOC.get(position);

		FragmentManager fragmentManager = getSupportFragmentManager();
		fragmentManager.beginTransaction().replace(R.id.container,
		// PlaceholderFragment.newInstance(position)).commit();
				assoc.getFragmentFactory().create()).commit();
	}

	public void onSectionAttached(int number) {
		switch (number) {
		case 1:
			mTitle = getString(R.string.title_section1);
			break;
		case 2:
			mTitle = getString(R.string.title_section2);
			break;
		case 3:
			mTitle = getString(R.string.title_section3);
			break;
		}
	}

	public void restoreActionBar() {
		ActionBar actionBar = getSupportActionBar();
		actionBar.setNavigationMode(ActionBar.NAVIGATION_MODE_STANDARD);
		actionBar.setDisplayShowTitleEnabled(true);
		actionBar.setTitle(mTitle);
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		if (!mNavigationDrawerFragment.isDrawerOpen()) {
			getMenuInflater().inflate(R.menu.main, menu);
			restoreActionBar();
			return true;
		}
		return super.onCreateOptionsMenu(menu);
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		// Handle action bar item clicks here. The action bar will
		// automatically handle clicks on the Home/Up button, so long
		// as you specify a parent activity in AndroidManifest.xml.
		int id = item.getItemId();

		switch (id) {
		case (R.id.action_example):
			// menu example
			return true;
		case (R.id.action_settings):
			// mennu settings
			return true;
		default:
			return super.onOptionsItemSelected(item);
		}

	}

	private void test() {
		// Acquire a reference to the system Location Manager
		LocationManager locationManager = (LocationManager) this
				.getSystemService(Context.LOCATION_SERVICE);

		Criteria criteria = new Criteria();
		String provider = locationManager.getBestProvider(criteria, false);
		Location location = locationManager.getLastKnownLocation(provider);

		// Initialize the location fields
		if (location != null) {
			System.out.println("Provider " + provider + " has been selected.");
			float lat = (float) (location.getLatitude());
			float lng = (float) (location.getLongitude());
			Log.i(BaitFragment.class.getName(), String.valueOf(lat));
			Log.i(BaitFragment.class.getName(), String.valueOf(lng));
		} else {
			Log.i(BaitFragment.class.getName(), "Provider not available");
			Log.i(BaitFragment.class.getName(), "Provider not available");
		}
		

		// Define a listener that responds to location updates
		LocationListener locationListener = new LocationListener() {
			public void onLocationChanged(Location location) {
				Log.i(BaitFragment.class.getName(), "Location updated " + location);
			}

			public void onStatusChanged(String provider, int status,
					Bundle extras) {
				Log.i(BaitFragment.class.getName(), "Status changed " + status);
			}

			public void onProviderEnabled(String provider) {

				Log.i(BaitFragment.class.getName(), "Provider enabled");
			}

			public void onProviderDisabled(String provider) {
				Log.i(BaitFragment.class.getName(), "Provider disabled");

			}
		};

		// Register the listener with the Location Manager to receive location
		// updates
		locationManager.requestLocationUpdates(LocationManager.GPS_PROVIDER, 10, 1, locationListener);
	}
}
