package fr.cnam.pecheurduleman.businessLogicLayer;

import java.util.List;

import fr.cnam.pecheurduleman.bean.Family;
import fr.cnam.pecheurduleman.bean.Fish;
import fr.cnam.pecheurduleman.dataAccessLayer.FamilyDAO;
import fr.cnam.pecheurduleman.dataAccessLayer.FishDAO;
import fr.cnam.pecheurduleman.dataAccessLayer.ListAll;
import fr.cnam.pecheurduleman.dataAccessLayer.db4o.FamilyDb4o;
import fr.cnam.pecheurduleman.dataAccessLayer.db4o.FishDb4o;
import fr.cnam.pecheurduleman.tool.StringUtil;

public class FishBO implements ListAll<Fish> {
	
	private final FishDAO fishDao;
	private final FamilyDAO familyDao;

	public FishBO() {
		super();
		fishDao = new FishDb4o();
		familyDao = new FamilyDb4o();
	}

	public void createOrUpdate(Fish bean) {
		// format entry
		bean.setName(StringUtil.capitalizeFirst(bean.getName()));
		bean.getFamily().setName(StringUtil.capitalizeFirst(bean.getFamily().getName()));
				
		// search ref and set pointer
		Family family = familyDao.find(bean.getFamily());
		if (family == null) {
			familyDao.create(bean.getFamily());
		} else {
			bean.setFamily(family);
		}

		// verify that fish does not already exists on db
		Fish existing = fishDao.find(new Fish(bean.getName(), null));
		if (existing == null) {
			// create
			fishDao.create(bean);
		} else {
			// update
			fishDao.update(bean, existing);
		}
		
	}

	@Override
	public List<Fish> listAll() {
		return fishDao.listAll();
	}

}
