package fr.cnam.pecheurduleman.dataAccessLayer.db4o;

import java.lang.reflect.Field;

import android.util.Log;

import com.db4o.ObjectContainer;
import com.db4o.ObjectSet;

import fr.cnam.pecheurduleman.bean.Bean;
import fr.cnam.pecheurduleman.dataAccessLayer.DAO;

public class BeanDb4o<B extends Bean> implements DAO<B> {

	@Override
	public void create(B bean) {
		Log.i(this.getClass().getName(), "DAO create [" + bean + "]");

		ObjectContainer db = DataSourceDb4o.getInstance().getDB();
		db.store(bean);
		db.commit();
	}

	@Override
	public void update(B bean, B beanToUpdate) {
		Log.i(this.getClass().getName(), "DAO update [" + beanToUpdate + "] with values of [" + bean + "]");

		// update it by reflexion
		try {
			for (Field field : beanToUpdate.getClass().getFields()) {
				field.setAccessible(true);
				field.set(beanToUpdate, field.get(bean));
			}

			// store it
			ObjectContainer db = DataSourceDb4o.getInstance().getDB();
			db.store(beanToUpdate);
			db.commit();

		} catch (IllegalAccessException e) {
			throw new RuntimeException("Cannot copy field !");
		} catch (IllegalArgumentException e) {
			throw new RuntimeException("Cannot copy field !");
		}
	}

	@Override
	public void delete(B bean) {
		Log.i(this.getClass().getName(), "DAO delete [" + bean + "]");

		ObjectContainer db = DataSourceDb4o.getInstance().getDB();
		db.delete(bean);
		db.commit();
		
	}

	@Override
	public B find(B bean) {
		ObjectContainer db = DataSourceDb4o.getInstance().getDB();
		ObjectSet<B> result = db.queryByExample(bean);
		// search on result the first element
		if (result.hasNext()) {
			Log.i(this.getClass().getName(), "DAO search [" + bean + "] found");
			return result.next();
		}

		// else, no result then null
		Log.i(this.getClass().getName(), "DAO search [" + bean + "] not found");
		return null;
	}

}
