package fr.cnam.pecheurduleman.dataAccessLayer.db4o;

import java.io.File;

import android.os.Environment;
import android.util.Log;

import com.db4o.Db4oEmbedded;
import com.db4o.ObjectContainer;
import com.db4o.config.EmbeddedConfiguration;

import fr.cnam.pecheurduleman.dataAccessLayer.DataSource;

public class DataSourceDb4o implements DataSource<ObjectContainer> {

	private static DataSourceDb4o singleton;
	private static final String DB_PATH = 
			Environment.getExternalStorageDirectory().toString()
			+ File.separator 
			+ "PecheurDuLeman"
			+ File.separator;
	public static final String DB_FILE = DB_PATH + "db.db4o";

	private ObjectContainer db = null;

	@Override
	public ObjectContainer getDB() {
		if (db == null)
			open();
		return db;
	}

	@Override
	public void open() {
		File directory = new File(DB_PATH);
		if (!directory.exists()) {
			Log.w(this.getClass().getName(), "Create db4object directory [" + directory + "]");
			directory.mkdirs();
		}

		if (new File(DB_FILE).exists()) {
			Log.i(this.getClass().getName(), "Store db4object database to [" + DB_FILE + "]");
		} else {
			Log.i(this.getClass().getName(), "Create db4object database to [" + DB_FILE + "]");
		}

		EmbeddedConfiguration config = Db4oEmbedded.newConfiguration();
		db = Db4oEmbedded.openFile(config, DB_FILE);
	}

	@Override
	public void close() {
		db.close();
	}

	private DataSourceDb4o() {
	}

	public synchronized static DataSourceDb4o getInstance() {
		if (singleton == null) {
			singleton = new DataSourceDb4o();
		}

		return singleton;
	}

}
