package fr.cyann.android.billingService;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.json.JSONException;

import android.app.Activity;
import android.app.PendingIntent;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.IntentSender.SendIntentException;
import android.content.ServiceConnection;
import android.os.Bundle;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.Log;

import com.android.vending.billing.IInAppBillingService;

public class BillingService implements IabConstants {

	private static BillingService singleton = null;

	private IInAppBillingService billingService;
	private Activity activity;

	// service
	private ServiceConnection serviceConn = new ServiceConnection() {

		@Override
		public void onServiceDisconnected(ComponentName name) {
			billingService = null;
		}

		@Override
		public void onServiceConnected(ComponentName name, IBinder service) {
			billingService = IInAppBillingService.Stub.asInterface(service);
		}
	};

	// function
	private void checkAvailability () throws IabException {
		if (billingService == null) {
			throw new IabException(BILLING_RESPONSE_RESULT_ERROR, "Billing service not initialized");
		}
	}
	
	// constructor
	private BillingService(final Activity context) {
		this.activity = context;
	}

	public static BillingService getInstance(Activity activity) {
		if (singleton == null) {
			singleton = new BillingService(activity);
		}
		return singleton;
	}
	
	// methods
	public void initialize() {
		activity.bindService(new Intent(
				"com.android.vending.billing.InAppBillingService.BIND"),
				serviceConn, Context.BIND_AUTO_CREATE);
	}

	public List<SkuDetail> getSkuDetails(String... keys)
			throws IabException {

		checkAvailability();
		
		List<SkuDetail> result = new ArrayList<SkuDetail>();

		try {

			// create list
			ArrayList<String> skuList = new ArrayList<String>();
			skuList.addAll(Arrays.asList(keys));
			Bundle querySkus = new Bundle();
			querySkus.putStringArrayList("ITEM_ID_LIST", skuList);
			
			// call service sku detail
			Bundle skuDetails = billingService.getSkuDetails(3,
					activity.getPackageName(), "inapp", querySkus);

			Log.d(this.getClass().getName(), skuDetails.getStringArrayList("DETAILS_LIST").toString());
			
			// response
			int response = skuDetails.getInt("RESPONSE_CODE");
			if (response == BILLING_RESPONSE_RESULT_OK) {
				ArrayList<String> detailList = skuDetails
						.getStringArrayList("DETAILS_LIST");

				// loop on responses
				for (String detail : detailList) {
					result.add(new SkuDetail(detail));
				}
			} else {
				throw new IabException(response, "Unable to get SkuDetails");
			}
		} catch (RemoteException e) {
			throw new IabException(BILLING_RESPONSE_RESULT_ERROR, e);
		} catch (JSONException e) {
			throw new IabException(BILLING_RESPONSE_RESULT_ERROR, e);
		}

		return result;
	}

	public static final int DEFAULT_REQUEST_CODE = 1001;
	
	public void purchase(String key) throws IabException {
		
		checkAvailability();
		
		try {
			Bundle buyIntentBundle = billingService.getBuyIntent(3, activity.getPackageName(), key, "inapp", "developper payload");

			int response = buyIntentBundle.getInt("RESPONSE_CODE");
			if (response == BILLING_RESPONSE_RESULT_OK) {
				PendingIntent pendingIntent = buyIntentBundle.getParcelable("BUY_INTENT");
				activity.startIntentSenderForResult(pendingIntent.getIntentSender(),
						DEFAULT_REQUEST_CODE, new Intent(), Integer.valueOf(0),
						Integer.valueOf(0), Integer.valueOf(0));
			}else {
				throw new IabException(response, "Unable to get SkuDetails");
			}
		} catch (RemoteException e) {
			throw new IabException(BILLING_RESPONSE_RESULT_ERROR, e);
		} catch (SendIntentException e) {
			throw new IabException(BILLING_RESPONSE_RESULT_ERROR, e);
		}
	}
	
	public Purchase handleActivityResult(int requestCode, int resultCode, Intent data) throws IabException {
		if (requestCode == DEFAULT_REQUEST_CODE) {
			int responseCode = data.getIntExtra("RESPONSE_CODE", 0);
			String purchaseData = data.getStringExtra("INAPP_PURCHASE_DATA");
			String dataSignature = data.getStringExtra("INAPP_DATA_SIGNATURE");

			if (resultCode == Activity.RESULT_OK && responseCode == BILLING_RESPONSE_RESULT_OK) {
				try {
					return new Purchase("inapp", purchaseData, dataSignature);
					
				} catch (JSONException e) {
					throw new IabException(BILLING_RESPONSE_RESULT_ERROR, e);
				}
			} else {
				throw new IabException(responseCode, "Unable to Purchase");
			}
		}
		return null;
	}
	
}
